#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the Head Pose Image dataset."""

from tensorbay.opendataset.HeadPoseImage.loader import HeadPoseImage

__all__ = ["HeadPoseImage"]
